#ifndef _ETHER_H_
#define _ETHER_H_
/* === COPYRIGHT 2000 (C) ========================= TOM HENDRICK ===

   FILE:                                                     ether.h

   DESCRIPTION:
      Defines the function prototypes and data structures for dealing
      local ethernet devices and interfaces.

   $REVISION:$
   
   LICENSE:
      This file, and the files included within the tipxd project are
      distributed under the GNU Public License(GPL).  Please read the
      LICENSE file included with this distribution or consult the license
      on the web at http://www.opensource.org/licenses/gpl-license.html

   =========== T I P X D . S O U R C E F O R G E . N E T =========== */


/* -----------------------------------------------------------------
   PREPROCESSOR INCLUDES
   ----------------------------------------------------------------- */
#include <sys/socket.h>
#include <netinet/in.h>
#include <netinet/if_ether.h>

#include "select.h"

/* -----------------------------------------------------------------
   STATIC DATA AND GLOBAL CONSTANTS
   ----------------------------------------------------------------- */
#define PROTO_802_3_MASK 0x01
#define PROTO_802_2_MASK 0x02
#define PROTO_SNAP_MASK  0x04
#define PROTO_II_MASK    0x08

#define PROTO_BROADCAST  0x10

/* -----------------------------------------------------------------
   PUBLIC DATA TYPES
   ----------------------------------------------------------------- */

/*
 * This structure defines a specific protocol socket that is open on
 * a specfic device.
 */
typedef struct _protoinfo_t {
   unsigned short  protocol;         /* ETH_P_XXXX constant */
   unsigned short  flags;            /* PROTO_XXXX constants */
   unsigned char   name[16];         /* String name, used for quick display */
   selectinfo_t   *selectinfo;       /* For maintaining the fd */
   unsigned long   bytes_rcvd;       /* Statistics for this socket */
} protoinfo_t;

/*
 * This is a structure used to define a specific device that we are going
 * to be listening for IPX packets on.
 */
typedef struct _etherinfo_t {
   unsigned long  id;
   unsigned char  name[16];
   unsigned short ifindex;
   unsigned char  hwaddr[ETHER_ADDR_LEN];
   unsigned int   protocount;
   unsigned int   protomask;
   protoinfo_t   *protocols;

   struct _etherinfo_t *next;
} etherinfo_t;

/* -----------------------------------------------------------------
   GLOBAL AND OTHERWISE EXPORTED DATA
   ----------------------------------------------------------------- */


/* -----------------------------------------------------------------
   PUBLIC FUNCTION PROTOTYPES
   ----------------------------------------------------------------- */

/* Verify contentst of an etherinfo structure */
extern int verify_ether( etherinfo_t *info );

/* Dump these to a logfile in human-readable format */
extern void dump_proto( FILE *fp, protoinfo_t *info );
extern void dump_ether( FILE *fp, etherinfo_t *info );

/* Send to a file descriptor in machine-readable format */
extern void send_proto( int fd, protoinfo_t *info );
extern void send_ether( int fd, etherinfo_t *info );

/* List functions */
extern void add_ether( etherinfo_t *ether );

/* Convert an ethernet address to a string */
extern char *ether_address_to_str( const unsigned char * );

/* Operation functions for the selectinfo */
extern void open_ipx ( struct _selectinfo_t *, void * );
extern void write_ipx( struct _selectinfo_t *, void *, char *, size_t );
extern void read_ipx ( struct _selectinfo_t *, void * );

/*
 * We don't have any special requirements for closing or for errors on IPX
 * sockets, so we can use the general functions from select.c
 */
#define error_ipx error_general
#define close_ipx close_general

#endif /* _ETHER_H_ */
