/* === COPYRIGHT 2000 (C) ========================= TOM HENDRICK ===

   FILE:                                                      log.c

   DESCRIPTION:
      Wrapper for syslog() or STDERR, depending on user selection.


   $REVISION:$
   
   LICENSE:
      This file, and the files included within the tipxd project are
      distributed under the GNU Public License(GPL).  Please read the
      LICENSE file included with this distribution or consult the license
      on the web at http://www.opensource.org/licenses/gpl-license.html

   =========== T I P X D . S O U R C E F O R G E . N E T =========== */

/* -----------------------------------------------------------------
   PREPROCESSOR INCLUDES
   ----------------------------------------------------------------- */
#include <syslog.h>
#include <time.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include "main.h"
#include "log.h"

/* -----------------------------------------------------------------
   
   FUNCTION:                                       tipxd_log( )

   DESCRIPTION:
      Writes out a log entry, either to Syslog or to STDERR.

   ARGUMENTS:
      Syslog priority and message

   RETURN VALUE:
      void

   ----------------------------------------------------------------- */
void tipxd_log(int priority, char *format, ...  )
{
   va_list ap;
   char log_entry[LOG_ENTRY_SIZE];
   
   /* Take the format and variables and expand them out into a string,
      so that we can pass it on to syslog if necessary. No buffer overflow,
      aren't I good? :)
   */
   va_start(ap,format);
   vsnprintf(log_entry,LOG_ENTRY_SIZE-1,format,ap);
   
   if (sysinfo.opt_flags & OPT_STDERR) {
/* To do: add something useful like timestamping instead of silly pre-identifier */
       fprintf(stderr,"[TIPXD LOG] %s\n",log_entry);
   } else {
       syslog(priority,log_entry);
   }

   return;
}
